indexing
	description: "An option that needs a yes or no parameter"
	author: "Bernd Schoeller"
	copyright: "(c) 2006 Bernd Schoeller (bernd@fams.de)"
	license: "see included README.txt file"
	date: "$Date: 2006/03/27 08:22:34 $"
	revision: "$Revision: 1.3 $"

class OP_BOOLEAN_OPTION

inherit
	
	OP_OPTION_WITH_PARAMETER [BOOLEAN]
		redefine
			initialize
		end
	
create

	make,
	make_with_long_form,
	make_with_short_form
	
feature {NONE} -- Initialization

	initialize is
			-- Perform the common initialization steps.
		do
			Precursor {OP_OPTION_WITH_PARAMETER}
			set_parameter_description ("yes|no")
		end

feature -- Constants

	false_strings: ARRAY [STRING] is 
			-- Values that describe `false'
		once
			Result := << "no","n","0","false","f" >>
			Result.compare_objects
		end
		
	true_strings: ARRAY [STRING] is 
			-- Values that describe `true'
		once
			Result := << "yes","y","1","true","t" >>
			Result.compare_objects
		end

feature -- Access

	is_false: BOOLEAN is
			-- Was the option set to False?
		do
			Result := not is_true
		end

	is_true: BOOLEAN is
			-- Was the option set to True?
		do
			Result := was_found and then parameter			
		end
	
	parameters: DS_LIST [BOOLEAN]
	
feature {OP_PARSER} -- Parser Interface

	reset is
			-- Reset the option to a clean state before parsing.
		do
			create {DS_LINKED_LIST [BOOLEAN]} parameters.make
		end

	record_occurrence (a_parser: OP_PARSER) is
			-- This option was found during parsing by `a_parser'.
		local
			error: OP_ERROR
		do
			if true_strings.has (a_parser.last_option_parameter) then
				parameters.force_last (True)
			elseif false_strings.has (a_parser.last_option_parameter) then
				parameters.force_last (False)
			else
				create error.make_invalid_parameter_error (Current, a_parser.last_option_parameter)
				a_parser.error_handler.report_error (error)				
			end
		end
		
invariant
	
	true_not_false: is_true = not is_false

end
